@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -37,7 +37,7 @@ public:
         lay->addWidget(mCharSelect);
 
         QPushButton *okButton = mButtonBox->button(QDialogButtonBox::Ok);
-        okButton->setText(i18n("Insert"));
+        okButton->setText(i18nc("@action:button", "Insert"));
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         lay->addWidget(mButtonBox);
         q->connect(mButtonBox, &QDialogButtonBox::accepted, q, &QDialog::accept);
@@ -50,7 +50,7 @@ public:
 
     void addSelectButton()
     {
-        mSelectButton = new QPushButton(i18n("Select"));
+        mSelectButton = new QPushButton(i18nc("@action:button", "Select"), q);
         mButtonBox->addButton(mSelectButton, QDialogButtonBox::ActionRole);
         q->connect(mSelectButton, &QPushButton::clicked, q, [this]() {
             _k_slotInsertChar();
@@ -71,14 +71,14 @@ void SelectSpecialCharDialogPrivate::readConfig()
 {
     q->create(); // ensure a window is created
     q->windowHandle()->resize(QSize(300, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySelectSpecialCharDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(mySelectSpecialCharDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(q->windowHandle(), group);
     q->resize(q->windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SelectSpecialCharDialogPrivate::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(mySelectSpecialCharDialogConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(mySelectSpecialCharDialogConfigGroupName));
     KWindowConfig::saveWindowSize(q->windowHandle(), group);
 }
 
