@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@
 QTEST_MAIN(AutoCorrectionTest)
 
 #ifndef Q_OS_WIN
-void initLocale()
+static void initLocale()
 {
     setenv("LC_ALL", "en_US.utf-8", 1);
 }
