@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,7 +22,7 @@ void ImportExportAutocorrectionLibreOfficeTest::shouldImportExport()
 {
     QFETCH(QString, filename);
 
-    const QString originalFile = QLatin1String(AUTOCORRECTION_DATA_DIR) + QLatin1Char('/') + filename;
+    const QString originalFile = QLatin1StringView(AUTOCORRECTION_DATA_DIR) + QLatin1Char('/') + filename;
 
     // First step
     TextAutoCorrectionCore::ImportLibreOfficeAutocorrection import;
