@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,13 +17,13 @@ public:
     ExportLibreOfficeAutocorrection();
     ~ExportLibreOfficeAutocorrection() override;
 
-    Q_REQUIRED_RESULT bool exportData(const QString &language, const QString &fileName, QString &errorMessage, const QString &writablePath) override;
+    [[nodiscard]] bool exportData(const QString &language, const QString &fileName, QString &errorMessage, const QString &writablePath) override;
 
 private:
-    Q_REQUIRED_RESULT bool exportDocumentList();
-    Q_REQUIRED_RESULT bool exportSentenceExceptList();
-    Q_REQUIRED_RESULT bool exportWordExceptList();
-    Q_REQUIRED_RESULT bool exportManifest();
+    [[nodiscard]] bool exportDocumentList();
+    [[nodiscard]] bool exportSentenceExceptList();
+    [[nodiscard]] bool exportWordExceptList();
+    [[nodiscard]] bool exportManifest();
     KZip *mZip = nullptr;
 };
 }
