@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,8 +22,8 @@ TextAutoCorrectionSettings *TextAutoCorrectionSettings::self()
 }
 
 TextAutoCorrectionSettings::TextAutoCorrectionSettings()
+    : mConfigSyncTimer(new QTimer(this))
 {
-    mConfigSyncTimer = new QTimer(this);
     mConfigSyncTimer->setSingleShot(true);
     connect(mConfigSyncTimer, &QTimer::timeout, this, &TextAutoCorrectionSettings::slotSyncNow);
 }
