@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,11 +12,7 @@
 #include <TextAutoCorrectionCore/ImportKMailAutocorrection>
 #include <TextAutoCorrectionCore/ImportLibreOfficeAutocorrection>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-#include <TextAddonsWidgets/LineEditCatchReturnKey>
-#else
 #include <KLineEditEventHandler>
-#endif
 #include <TextAddonsWidgets/SelectSpecialCharDialog>
 
 #include <KLocalizedString>
@@ -64,18 +60,11 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     d->ui->add1->setEnabled(false);
     d->ui->add2->setEnabled(false);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-    TextAddonsWidgets::LineEditCatchReturnKey(d->ui->find, this);
-    TextAddonsWidgets::LineEditCatchReturnKey(d->ui->replace, this);
-    TextAddonsWidgets::LineEditCatchReturnKey(d->ui->abbreviation, this);
-    TextAddonsWidgets::LineEditCatchReturnKey(d->ui->twoUpperLetter, this);
-#else
     KLineEditEventHandler::catchReturnKey(d->ui->find);
     KLineEditEventHandler::catchReturnKey(d->ui->replace);
     KLineEditEventHandler::catchReturnKey(d->ui->abbreviation);
     KLineEditEventHandler::catchReturnKey(d->ui->twoUpperLetter);
 
-#endif
     connect(d->ui->autoChangeFormat, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->autoFormatUrl, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->upperCase, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
@@ -138,13 +127,8 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     connect(d->ui->customWritablePath, &QLineEdit::textChanged, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->customSystemPath, &QLineEdit::textChanged, this, &AutoCorrectionWidget::emitChanged);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-    TextAddonsWidgets::LineEditCatchReturnKey(d->ui->customWritablePath, parent);
-    TextAddonsWidgets::LineEditCatchReturnKey(d->ui->customSystemPath, parent);
-#else
     KLineEditEventHandler::catchReturnKey(d->ui->customWritablePath);
     KLineEditEventHandler::catchReturnKey(d->ui->customSystemPath);
-#endif
 
     connect(d->ui->customWritablePathToolButton, &QToolButton::clicked, this, [this]() {
         const QString path = QFileDialog::getExistingDirectory(this, i18n("Select Custom Writable Path"));
@@ -162,11 +146,11 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     auto menu = new QMenu(this);
     d->ui->importAutoCorrection->setMenu(menu);
 
-    auto act = new QAction(i18n("LibreOffice Autocorrection"), this);
+    auto act = new QAction(i18nc("@action", "LibreOffice Autocorrection"), this);
     act->setData(QVariant::fromValue(AutoCorrectionWidget::LibreOffice));
     menu->addAction(act);
 
-    act = new QAction(i18n("KMail/Calligra Autocorrection"), this);
+    act = new QAction(i18nc("@action", "KMail/Calligra Autocorrection"), this);
     act->setData(QVariant::fromValue(AutoCorrectionWidget::KMail));
     menu->addAction(act);
 
@@ -444,7 +428,7 @@ void AutoCorrectionWidget::addAutocorrectEntry()
     const QString find = d->ui->find->text();
     const QString replace = d->ui->replace->text();
     if (find == replace) {
-        KMessageBox::error(this, i18n("\"Replace\" string is the same as \"Find\" string."), i18n("Add Autocorrection Entry"));
+        KMessageBox::error(this, i18n("\"Replace\" string is the same as \"Find\" string."), i18nc("@title:window", "Add Autocorrection Entry"));
         return;
     }
 
@@ -671,7 +655,7 @@ void AutoCorrectionWidget::slotImportAutoCorrection(QAction *act)
                 d->ui->abbreviationList->clear();
                 d->ui->abbreviationList->addItems(d->m_upperCaseExceptions.values());
             } else {
-                KMessageBox::error(this, messageError, i18n("Import Autocorrection File"));
+                KMessageBox::error(this, messageError, i18nc("@title:window", "Import Autocorrection File"));
             }
             delete importAutoCorrection;
         }
@@ -696,7 +680,7 @@ void AutoCorrectionWidget::changeLanguage()
     if (d->mWasChanged) {
         const int rc = KMessageBox::warningTwoActions(this,
                                                       i18n("Language was changed, do you want to save config for previous language?"),
-                                                      i18n("Save config"),
+                                                      i18nc("@title:window", "Save config"),
                                                       KStandardGuiItem::save(),
                                                       KStandardGuiItem::discard());
         if (rc == KMessageBox::ButtonCode::PrimaryAction) {
@@ -731,10 +715,10 @@ void AutoCorrectionWidget::loadGlobalAutoCorrectionAndException()
 void AutoCorrectionWidget::slotExportAutoCorrection()
 {
     if (d->mWasChanged) {
-        KMessageBox::error(this, i18n("Please save changes before exporting settings."), i18n("Export Autocorrection File"));
+        KMessageBox::error(this, i18n("Please save changes before exporting settings."), i18nc("@title:window", "Export Autocorrection File"));
         return;
     }
-    const QString saveUrl = QFileDialog::getSaveFileName(this, i18n("Export Autocorrection File"), QDir::homePath());
+    const QString saveUrl = QFileDialog::getSaveFileName(this, i18nc("@title:window", "Export Autocorrection File"), QDir::homePath());
     if (saveUrl.isEmpty()) {
         return;
     }
