@@ -1,47 +1,44 @@
 /*
-   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "plaintexteditor.h"
-
 #include "config-textcustomeditor.h"
 #include "widgets/textmessageindicator.h"
-#include <KConfig>
-#include <KConfigGroup>
-#include <KCursor>
-#include <KIO/KUriFilterSearchProviderActions>
-#include <KLocalizedString>
-#include <KSharedConfig>
-#include <KStandardAction>
-#include <KStandardGuiItem>
-#include <QActionGroup>
-#include <QIcon>
 
 #if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
-#include <Sonnet/Dialog>
 #include <TextEmoticonsWidgets/EmoticonTextEditAction>
-#include <sonnet/backgroundchecker.h>
 
+#include <KConfig>
+#include <KConfigGroup>
+#include <KCursor>
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
+#include <KIO/KUriFilterSearchProviderActions>
+#endif
 #include <KColorScheme>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KStandardActions>
+#include <Sonnet/BackgroundChecker>
+#include <Sonnet/Dialog>
+#include <Sonnet/Highlighter>
+#include <Sonnet/SpellCheckDecorator>
+#include <Sonnet/Speller>
+
+#include <QActionGroup>
 #include <QApplication>
 #include <QClipboard>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
+#include <QIcon>
 #include <QMenu>
 #include <QScrollBar>
 #include <QShortcut>
 #include <QTextDocumentFragment>
 
-#include <sonnet/spellcheckdecorator.h>
-
-#include <sonnet/speller.h>
-
-#include <Sonnet/Highlighter>
-
 using namespace TextCustomEditor;
+using namespace Qt::Literals::StringLiterals;
 
 class Q_DECL_HIDDEN PlainTextEditor::PlainTextEditorPrivate
 {
@@ -49,15 +46,19 @@ public:
     PlainTextEditorPrivate(PlainTextEditor *qq)
         : q(qq)
         , mTextIndicator(new TextCustomEditor::TextMessageIndicator(q))
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
+#endif
     {
         KConfig sonnetKConfig(QStringLiteral("sonnetrc"));
-        KConfigGroup group(&sonnetKConfig, QLatin1String("Spelling"));
+        KConfigGroup group(&sonnetKConfig, "Spelling"_L1);
         checkSpellingEnabled = group.readEntry("checkerEnabledByDefault", false);
         supportFeatures |= PlainTextEditor::Search;
         supportFeatures |= PlainTextEditor::SpellChecking;
         supportFeatures |= PlainTextEditor::TextToSpeech;
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         supportFeatures |= PlainTextEditor::AllowWebShortcut;
+#endif
     }
 
     ~PlainTextEditorPrivate()
@@ -69,7 +70,9 @@ public:
     QStringList ignoreSpellCheckingWords;
     PlainTextEditor *const q;
     TextCustomEditor::TextMessageIndicator *const mTextIndicator;
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     KIO::KUriFilterSearchProviderActions *const webshortcutMenuManager;
+#endif
     Sonnet::SpellCheckDecorator *richTextDecorator = nullptr;
     Sonnet::Speller *speller = nullptr;
 
@@ -120,7 +123,16 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
         const bool emptyDocument = document()->isEmpty();
         if (!isReadOnly()) {
             const QList<QAction *> actionList = popup->actions();
-            enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
+            enum {
+                UndoAct,
+                RedoAct,
+                CutAct,
+                CopyAct,
+                PasteAct,
+                ClearAct,
+                SelectAllAct,
+                NCountActs
+            };
             QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
             if (idx < actionList.count()) {
@@ -128,7 +140,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             }
             if (separatorAction) {
                 if (!emptyDocument) {
-                    QAction *clearAllAction = KStandardAction::clear(this, &PlainTextEditor::slotUndoableClear, popup);
+                    QAction *clearAllAction = KStandardActions::clear(this, &PlainTextEditor::slotUndoableClear, popup);
                     popup->insertAction(separatorAction, clearAllAction);
                 }
             }
@@ -136,13 +148,13 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
         if (d->supportFeatures & Search) {
             popup->addSeparator();
             if (!emptyDocument) {
-                QAction *findAction = KStandardAction::find(this, &PlainTextEditor::findText, popup);
+                QAction *findAction = KStandardActions::find(this, &PlainTextEditor::findText, popup);
                 popup->addAction(findAction);
                 popup->addSeparator();
             }
             if (!isReadOnly()) {
                 if (!emptyDocument) {
-                    QAction *replaceAction = KStandardAction::replace(this, &PlainTextEditor::replaceText, popup);
+                    QAction *replaceAction = KStandardActions::replace(this, &PlainTextEditor::replaceText, popup);
                     popup->addAction(replaceAction);
                     popup->addSeparator();
                 }
@@ -158,7 +170,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             if (!d->speller->availableBackends().isEmpty()) {
                 if (!emptyDocument) {
                     popup->addAction(QIcon::fromTheme(QStringLiteral("tools-check-spelling")),
-                                     i18n("Check Spelling..."),
+                                     i18n("Check Spelling…"),
                                      this,
                                      &PlainTextEditor::slotCheckSpelling);
                     popup->addSeparator();
@@ -203,12 +215,14 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             }
 #endif
         }
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         if (webShortcutSupport() && textCursor().hasSelection()) {
             popup->addSeparator();
             const QString selectedText = textCursor().selectedText();
             d->webshortcutMenuManager->setSelectedText(selectedText);
             d->webshortcutMenuManager->addWebShortcutsToMenu(popup);
         }
+#endif
         if (emojiSupport()) {
             popup->addSeparator();
             auto action = new TextEmoticonsWidgets::EmoticonTextEditAction(this);
@@ -312,16 +326,24 @@ void PlainTextEditor::setSpellCheckingSupport(bool check)
 
 void PlainTextEditor::setWebShortcutSupport(bool b)
 {
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     if (b) {
         d->supportFeatures |= AllowWebShortcut;
     } else {
         d->supportFeatures = (d->supportFeatures & ~AllowWebShortcut);
     }
+#else
+    Q_UNUSED(b);
+#endif
 }
 
 bool PlainTextEditor::webShortcutSupport() const
 {
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     return d->supportFeatures & AllowWebShortcut;
+#else
+    return false;
+#endif
 }
 
 void PlainTextEditor::updateReadOnlyColor()
@@ -866,8 +888,8 @@ void PlainTextEditor::setSpellCheckingConfigFileName(const QString &_fileName)
 {
     d->spellCheckingConfigFileName = _fileName;
     KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-    if (config->hasGroup(QLatin1String("Spelling"))) {
-        KConfigGroup group(config, QLatin1String("Spelling"));
+    if (config->hasGroup("Spelling"_L1)) {
+        KConfigGroup group(config, "Spelling"_L1);
         d->checkSpellingEnabled = group.readEntry("checkerEnabledByDefault", false);
         d->spellCheckingLanguage = group.readEntry("Language", QString());
     }
@@ -905,7 +927,7 @@ void PlainTextEditor::setSpellCheckingLanguage(const QString &_language)
     if (_language != d->spellCheckingLanguage) {
         d->spellCheckingLanguage = _language;
         KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-        KConfigGroup group(config, QLatin1String("Spelling"));
+        KConfigGroup group(config, "Spelling"_L1);
         group.writeEntry("Language", d->spellCheckingLanguage);
         setCheckSpellingEnabled(checkSpellingEnabled());
 
@@ -917,7 +939,7 @@ void PlainTextEditor::slotToggleAutoSpellCheck()
 {
     setCheckSpellingEnabled(!checkSpellingEnabled());
     KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-    KConfigGroup group(config, QLatin1String("Spelling"));
+    KConfigGroup group(config, "Spelling"_L1);
     group.writeEntry("checkerEnabledByDefault", d->checkSpellingEnabled);
 }
 
