@@ -1,22 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtextbrowser.h"
-#include "textcustomeditor_debug.h"
 
 #include "widgets/textmessageindicator.h"
 #include <KCursor>
 #include <KLocalizedString>
-#include <KMessageBox>
-#include <KStandardAction>
-#include <KStandardGuiItem>
+#include <KStandardActions>
 #include <QIcon>
 
 #include "config-textcustomeditor.h"
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
 #include <KIO/KUriFilterSearchProviderActions>
+#endif
 #if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
@@ -38,11 +37,15 @@ public:
     RichTextBrowserPrivate(RichTextBrowser *qq)
         : q(qq)
         , textIndicator(new TextCustomEditor::TextMessageIndicator(q))
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
+#endif
     {
         supportFeatures |= RichTextBrowser::Search;
         supportFeatures |= RichTextBrowser::TextToSpeech;
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         supportFeatures |= RichTextBrowser::AllowWebShortcut;
+#endif
 
         // Workaround QTextEdit behavior: if the cursor points right after the link
         // and start typing, the char format is kept. If user wants to write normal
@@ -76,7 +79,9 @@ public:
     RichTextBrowser *const q;
     TextCustomEditor::TextMessageIndicator *const textIndicator;
     QTextDocumentFragment originalDoc;
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     KIO::KUriFilterSearchProviderActions *const webshortcutMenuManager;
+#endif
     RichTextBrowser::SupportFeatures supportFeatures;
     QColor mReadOnlyBackgroundColor;
     int mInitialFontSize;
@@ -128,14 +133,23 @@ QMenu *RichTextBrowser::mousePopupMenu(QPoint pos)
         const bool emptyDocument = document()->isEmpty();
         if (!isReadOnly()) {
             const QList<QAction *> actionList = popup->actions();
-            enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
+            enum {
+                UndoAct,
+                RedoAct,
+                CutAct,
+                CopyAct,
+                PasteAct,
+                ClearAct,
+                SelectAllAct,
+                NCountActs
+            };
             QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
             if (idx < actionList.count()) {
                 separatorAction = actionList.at(idx);
             }
             if (separatorAction) {
-                QAction *clearAllAction = KStandardAction::clear(this, &RichTextBrowser::slotUndoableClear, popup);
+                QAction *clearAllAction = KStandardActions::clear(this, &RichTextBrowser::slotUndoableClear, popup);
                 if (emptyDocument) {
                     clearAllAction->setEnabled(false);
                 }
@@ -144,7 +158,7 @@ QMenu *RichTextBrowser::mousePopupMenu(QPoint pos)
         }
         if (searchSupport()) {
             popup->addSeparator();
-            QAction *findAction = KStandardAction::find(this, &RichTextBrowser::findText, popup);
+            QAction *findAction = KStandardActions::find(this, &RichTextBrowser::findText, popup);
             popup->addAction(findAction);
             if (emptyDocument) {
                 findAction->setEnabled(false);
@@ -160,12 +174,14 @@ QMenu *RichTextBrowser::mousePopupMenu(QPoint pos)
             connect(speakAction, &QAction::triggered, this, &RichTextBrowser::slotSpeakText);
         }
 #endif
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         if (webShortcutSupport() && textCursor().hasSelection()) {
             popup->addSeparator();
             const QString selectedText = textCursor().selectedText();
             d->webshortcutMenuManager->setSelectedText(selectedText);
             d->webshortcutMenuManager->addWebShortcutsToMenu(popup);
         }
+#endif
         addExtraMenuEntry(popup, pos);
         return popup;
     }
@@ -185,16 +201,24 @@ void RichTextBrowser::slotSpeakText()
 
 void RichTextBrowser::setWebShortcutSupport(bool b)
 {
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     if (b) {
         d->supportFeatures |= AllowWebShortcut;
     } else {
         d->supportFeatures = (d->supportFeatures & ~AllowWebShortcut);
     }
+#else
+    Q_UNUSED(b);
+#endif
 }
 
 bool RichTextBrowser::webShortcutSupport() const
 {
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     return d->supportFeatures & AllowWebShortcut;
+#else
+    return false;
+#endif
 }
 
 void RichTextBrowser::setSearchSupport(bool b)
@@ -251,7 +275,7 @@ void RichTextBrowser::updateReadOnlyColor()
     }
 }
 
-static void deleteWord(QTextCursor cursor, QTextCursor::MoveOperation op)
+static void richTextDeleteWord(QTextCursor cursor, QTextCursor::MoveOperation op)
 {
     cursor.clearSelection();
     cursor.movePosition(op, QTextCursor::KeepAnchor);
@@ -260,12 +284,12 @@ static void deleteWord(QTextCursor cursor, QTextCursor::MoveOperation op)
 
 void RichTextBrowser::deleteWordBack()
 {
-    deleteWord(textCursor(), QTextCursor::PreviousWord);
+    richTextDeleteWord(textCursor(), QTextCursor::PreviousWord);
 }
 
 void RichTextBrowser::deleteWordForward()
 {
-    deleteWord(textCursor(), QTextCursor::WordRight);
+    richTextDeleteWord(textCursor(), QTextCursor::WordRight);
 }
 
 bool RichTextBrowser::event(QEvent *ev)
