@@ -1,43 +1,44 @@
 /*
-   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "richtexteditor.h"
-#include "textcustomeditor_debug.h"
-
-#include "widgets/textmessageindicator.h"
-#include <KConfig>
-#include <KConfigGroup>
-#include <KCursor>
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <KSharedConfig>
-#include <KStandardAction>
-#include <KStandardGuiItem>
-#include <QActionGroup>
-#include <QIcon>
 
 #include "config-textcustomeditor.h"
-#include <KIO/KUriFilterSearchProviderActions>
-#include <Sonnet/Dialog>
-#include <Sonnet/Highlighter>
-#include <sonnet/backgroundchecker.h>
-#include <sonnet/spellcheckdecorator.h>
-#include <sonnet/speller.h>
+#include "textcustomeditor_debug.h"
+#include "widgets/textmessageindicator.h"
+
 #if HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
 #include <TextEditTextToSpeech/TextToSpeech>
 #endif
 #include <TextEmoticonsWidgets/EmoticonTextEditAction>
 
 #include <KColorScheme>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KCursor>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <KStandardActions>
+#include <KStandardGuiItem>
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
+#include <KIO/KUriFilterSearchProviderActions>
+#endif
+#include <Sonnet/BackgroundChecker>
+#include <Sonnet/Dialog>
+#include <Sonnet/Highlighter>
+#include <Sonnet/SpellCheckDecorator>
+#include <Sonnet/Speller>
+
+#include <QActionGroup>
 #include <QApplication>
 #include <QClipboard>
 #include <QContextMenuEvent>
-#include <QDBusConnection>
-#include <QDBusConnectionInterface>
 #include <QDialogButtonBox>
+#include <QIcon>
 #include <QMenu>
 #include <QPushButton>
 #include <QScrollBar>
@@ -45,22 +46,28 @@
 #include <QTextDocumentFragment>
 
 using namespace TextCustomEditor;
+using namespace Qt::Literals::StringLiterals;
+
 class Q_DECL_HIDDEN RichTextEditor::RichTextEditorPrivate
 {
 public:
     RichTextEditorPrivate(RichTextEditor *qq)
         : q(qq)
         , textIndicator(new TextCustomEditor::TextMessageIndicator(q))
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
+#endif
     {
         KConfig sonnetKConfig(QStringLiteral("sonnetrc"));
-        KConfigGroup group(&sonnetKConfig, QLatin1String("Spelling"));
+        KConfigGroup group(&sonnetKConfig, "Spelling"_L1);
         checkSpellingEnabled = group.readEntry("checkerEnabledByDefault", false);
         supportFeatures |= RichTextEditor::Search;
         supportFeatures |= RichTextEditor::SpellChecking;
         supportFeatures |= RichTextEditor::TextToSpeech;
         supportFeatures |= RichTextEditor::AllowTab;
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         supportFeatures |= RichTextEditor::AllowWebShortcut;
+#endif
 
         // Workaround QTextEdit behavior: if the cursor points right after the link
         // and start typing, the char format is kept. If user wants to write normal
@@ -101,7 +108,9 @@ public:
     QTextDocumentFragment originalDoc;
     Sonnet::SpellCheckDecorator *richTextDecorator = nullptr;
     Sonnet::Speller *speller = nullptr;
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     KIO::KUriFilterSearchProviderActions *const webshortcutMenuManager;
+#endif
     RichTextEditor::SupportFeatures supportFeatures;
     QColor mReadOnlyBackgroundColor;
     int mInitialFontSize;
@@ -176,14 +185,23 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         const bool emptyDocument = document()->isEmpty();
         if (!isReadOnly()) {
             const QList<QAction *> actionList = popup->actions();
-            enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
+            enum {
+                UndoAct,
+                RedoAct,
+                CutAct,
+                CopyAct,
+                PasteAct,
+                ClearAct,
+                SelectAllAct,
+                NCountActs
+            };
             QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
             if (idx < actionList.count()) {
                 separatorAction = actionList.at(idx);
             }
             if (separatorAction) {
-                QAction *clearAllAction = KStandardAction::clear(this, &RichTextEditor::slotUndoableClear, popup);
+                QAction *clearAllAction = KStandardActions::clear(this, &RichTextEditor::slotUndoableClear, popup);
                 if (emptyDocument) {
                     clearAllAction->setEnabled(false);
                 }
@@ -192,14 +210,14 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         }
         if (searchSupport()) {
             popup->addSeparator();
-            QAction *findAction = KStandardAction::find(this, &RichTextEditor::findText, popup);
+            QAction *findAction = KStandardActions::find(this, &RichTextEditor::findText, popup);
             popup->addAction(findAction);
             if (emptyDocument) {
                 findAction->setEnabled(false);
             }
             popup->addSeparator();
             if (!isReadOnly()) {
-                QAction *act = KStandardAction::replace(this, &RichTextEditor::replaceText, popup);
+                QAction *act = KStandardActions::replace(this, &RichTextEditor::replaceText, popup);
                 popup->addAction(act);
                 if (emptyDocument) {
                     act->setEnabled(false);
@@ -216,7 +234,7 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
             }
             if (!d->speller->availableBackends().isEmpty()) {
                 QAction *spellCheckAction = popup->addAction(QIcon::fromTheme(QStringLiteral("tools-check-spelling")),
-                                                             i18n("Check Spelling..."),
+                                                             i18n("Check Spelling…"),
                                                              this,
                                                              &RichTextEditor::slotCheckSpelling);
                 if (emptyDocument) {
@@ -267,12 +285,14 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
             connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
         }
 #endif
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
         if (webShortcutSupport() && textCursor().hasSelection()) {
             popup->addSeparator();
             const QString selectedText = textCursor().selectedText();
             d->webshortcutMenuManager->setSelectedText(selectedText);
             d->webshortcutMenuManager->addWebShortcutsToMenu(popup);
         }
+#endif
         if (emojiSupport()) {
             popup->addSeparator();
             auto action = new TextEmoticonsWidgets::EmoticonTextEditAction(this);
@@ -303,16 +323,24 @@ void RichTextEditor::slotSpeakText()
 
 void RichTextEditor::setWebShortcutSupport(bool b)
 {
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     if (b) {
         d->supportFeatures |= AllowWebShortcut;
     } else {
         d->supportFeatures = (d->supportFeatures & ~AllowWebShortcut);
     }
+#else
+    Q_UNUSED(b);
+#endif
 }
 
 bool RichTextEditor::webShortcutSupport() const
 {
+#if HAVE_KTEXTADDONS_KIO_SUPPORT
     return d->supportFeatures & AllowWebShortcut;
+#else
+    return false;
+#endif
 }
 
 void RichTextEditor::setEmojiSupport(bool b)
@@ -504,7 +532,7 @@ void RichTextEditor::checkSpelling(bool force)
     auto spellDialog = new Sonnet::Dialog(backgroundSpellCheck, force ? this : nullptr);
     auto buttonBox = spellDialog->findChild<QDialogButtonBox *>();
     if (buttonBox) {
-        auto skipButton = new QPushButton(i18n("Skip"));
+        auto skipButton = new QPushButton(i18nc("@action:button", "Skip"));
         buttonBox->addButton(skipButton, QDialogButtonBox::ActionRole);
         connect(skipButton, &QPushButton::clicked, spellDialog, &Sonnet::Dialog::close);
         if (force) {
@@ -638,8 +666,8 @@ void RichTextEditor::setSpellCheckingConfigFileName(const QString &_fileName)
 {
     d->spellCheckingConfigFileName = _fileName;
     KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-    if (config->hasGroup(QLatin1String("Spelling"))) {
-        KConfigGroup group(config, QLatin1String("Spelling"));
+    if (config->hasGroup("Spelling"_L1)) {
+        KConfigGroup group(config, "Spelling"_L1);
         d->checkSpellingEnabled = group.readEntry("checkerEnabledByDefault", false);
         d->spellCheckingLanguage = group.readEntry("Language", QString());
     }
@@ -711,7 +739,7 @@ void RichTextEditor::setSpellCheckingLanguage(const QString &_language)
     if (_language != d->spellCheckingLanguage) {
         d->spellCheckingLanguage = _language;
         KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-        KConfigGroup group(config, QLatin1String("Spelling"));
+        KConfigGroup group(config, "Spelling"_L1);
         group.writeEntry("Language", d->spellCheckingLanguage);
 
         Q_EMIT languageChanged(_language);
@@ -722,7 +750,7 @@ void RichTextEditor::slotToggleAutoSpellCheck()
 {
     setCheckSpellingEnabled(!checkSpellingEnabled());
     KSharedConfig::Ptr config = KSharedConfig::openConfig(d->spellCheckingConfigFileName);
-    KConfigGroup group(config, QLatin1String("Spelling"));
+    KConfigGroup group(config, "Spelling"_L1);
     group.writeEntry("checkerEnabledByDefault", d->checkSpellingEnabled);
 }
 
