@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "texttospeechwidgettest.h"
-#include "abstracttexttospeechinterface.h"
+#include "texttospeechinterface.h"
 #include "texttospeechsliderwidget.h"
 #include "texttospeechwidget.h"
 #include <QHBoxLayout>
@@ -25,7 +25,7 @@ TextToSpeechWidgetTest::TextToSpeechWidgetTest(QObject *parent)
 
 void TextToSpeechWidgetTest::addInterface(TextEditTextToSpeech::TextToSpeechWidget *widget)
 {
-    auto interface = new TextEditTextToSpeech::AbstractTextToSpeechInterface(this);
+    auto interface = new TextEditTextToSpeech::TextToSpeechInterface(widget, this);
     widget->setTextToSpeechInterface(interface);
 }
 
