@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ TextToSpeechGui::TextToSpeechGui(QWidget *parent)
 
     QMenu *editMenu = menuBar()->addMenu(QStringLiteral("Edit"));
 
-    auto act = new QAction(i18n("Speech text"), this);
+    auto act = new QAction(i18nc("@action", "Speech text"), this);
     connect(act, &QAction::triggered, this, &TextToSpeechGui::slotTextToSpeech);
     editMenu->addAction(act);
     qDebug() << " isReady ? " << TextEditTextToSpeech::TextToSpeech::self()->isReady();
