@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,6 @@
 #include "texttospeechutil.h"
 
 #include <KConfig>
-#include <KConfigGroup>
 #include <QLocale>
 #include <QTextToSpeech>
 #include <QVector>
@@ -37,10 +36,7 @@ void TextToSpeech::reloadSettings()
     const QString engineName = settings.engineName;
     if (d->mDefaultEngine != engineName) {
         if (d->mTextToSpeech) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-            if (d->mTextToSpeech && (d->mTextToSpeech->engine() != engineName))
-#endif
-            {
+            if (d->mTextToSpeech && (d->mTextToSpeech->engine() != engineName)) {
                 disconnect(d->mTextToSpeech, &QTextToSpeech::stateChanged, this, &TextToSpeech::slotStateChanged);
                 delete d->mTextToSpeech;
                 d->mTextToSpeech = nullptr;
@@ -84,13 +80,11 @@ void TextToSpeech::slotStateChanged()
     case QTextToSpeech::Paused:
         state = TextToSpeech::Paused;
         break;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    case QTextToSpeech::BackendError:
-        state = TextToSpeech::BackendError;
-#else
     case QTextToSpeech::Error:
         state = TextToSpeech::BackendError;
-#endif
+        break;
+    case QTextToSpeech::Synthesizing:
+        state = TextToSpeech::Synthesizing;
         break;
     }
     Q_EMIT stateChanged(state);
@@ -98,11 +92,7 @@ void TextToSpeech::slotStateChanged()
 
 bool TextToSpeech::isReady() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    return d->mTextToSpeech->state() != QTextToSpeech::BackendError;
-#else
     return d->mTextToSpeech->state() != QTextToSpeech::Error;
-#endif
 }
 
 void TextToSpeech::say(const QString &text)
