@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,10 +25,10 @@ TextToSpeechActions::TextToSpeechActions(QObject *parent)
     : QObject(parent)
     , d(new TextEditTextToSpeech::TextToSpeechActionsPrivate)
 {
-    d->mStopAction = new QAction(i18n("Stop"), this);
+    d->mStopAction = new QAction(i18nc("@action", "Stop"), this);
     d->mStopAction->setObjectName(QStringLiteral("stopbutton"));
     d->mStopAction->setIcon(QIcon::fromTheme(QStringLiteral("media-playback-stop")));
-    d->mStopAction->setToolTip(i18n("Stop"));
+    d->mStopAction->setToolTip(i18nc("@info:tooltip", "Stop"));
     connect(d->mStopAction, &QAction::triggered, this, &TextToSpeechActions::slotStop);
 
     d->mPlayPauseAction = new QAction(this);
