@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -57,10 +57,7 @@ QLocale TextToSpeechConfigInterface::locale() const
 
 void TextToSpeechConfigInterface::setEngine(const QString &engineName)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
-    if (!mTextToSpeech || (mTextToSpeech && (mTextToSpeech->engine() != engineName)))
-#endif
-    {
+    if (!mTextToSpeech || (mTextToSpeech && (mTextToSpeech->engine() != engineName))) {
         delete mTextToSpeech;
         mTextToSpeech = new QTextToSpeech(engineName, this);
     }
@@ -93,9 +90,7 @@ QDebug operator<<(QDebug d, const TextEditTextToSpeech::TextToSpeechConfigInterf
     d << " Rate " << t.rate;
     d << " pitch " << t.pitch;
     d << " volume " << t.volume;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     d << " voice " << t.voice;
-#endif
     d << " localeName " << t.localeName;
     return d;
 }
