@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -30,11 +30,11 @@ public:
     explicit TextToSpeechConfigInterface(QObject *parent = nullptr);
     ~TextToSpeechConfigInterface() override;
 
-    Q_REQUIRED_RESULT QVector<QLocale> availableLocales() const;
-    Q_REQUIRED_RESULT QLocale locale() const;
+    [[nodiscard]] QVector<QLocale> availableLocales() const;
+    [[nodiscard]] QLocale locale() const;
 
-    Q_REQUIRED_RESULT QStringList availableEngines() const;
-    Q_REQUIRED_RESULT QVector<QVoice> availableVoices() const;
+    [[nodiscard]] QStringList availableEngines() const;
+    [[nodiscard]] QVector<QVoice> availableVoices() const;
     void setEngine(const QString &engineName);
     void testEngine(const EngineSettings &engineSettings);
     QTextToSpeech *mTextToSpeech = nullptr;
