@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,13 +20,13 @@ public:
 
     void setValue(int value);
     void setRange(int min, int max);
-    Q_REQUIRED_RESULT int value() const;
+    [[nodiscard]] int value() const;
 
 Q_SIGNALS:
     void valueChanged(int value);
 
 private:
-    void slotValueChanged(int value);
+    TEXTEDITTEXTTOSPEECH_NO_EXPORT void slotValueChanged(int value);
     QString mLabelInfo;
     QLabel *const mLabel;
     QSlider *const mSlider;
