@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ CustomEmojiIconManager::CustomEmojiIconManager(QObject *parent)
 {
 }
 
-CustomEmojiIconManager::~CustomEmojiIconManager()
-{
-}
+CustomEmojiIconManager::~CustomEmojiIconManager() = default;
 
 QIcon CustomEmojiIconManager::generateIcon(const QString &customIdentifier)
 {
