@@ -1,12 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "unicodeemoticon.h"
 #include "emoticonunicodeutils.h"
-#include <sstream>
 
 using namespace TextEmoticonsCore;
 UnicodeEmoticon::UnicodeEmoticon() = default;
@@ -42,28 +41,6 @@ QString UnicodeEmoticon::unicodeDisplay() const
     return mCachedHtml;
 }
 
-// input: codepoints in hex like 1f9d7-1f3fb-2640
-// output: QString with 3 ucs4 code points for the above, which is in fact 5 QChars.
-QString UnicodeEmoticon::escapeUnicodeEmoji(const QString &pString)
-{
-    QString retString;
-
-    const QStringList parts = pString.split(QLatin1Char('-'));
-    for (const auto &item : parts) {
-        bool ok;
-        const int part = item.toInt(&ok, 16);
-        Q_ASSERT(ok);
-        if (QChar::requiresSurrogates(part)) {
-            retString += QChar::highSurrogate(part);
-            retString += QChar::lowSurrogate(part);
-        } else {
-            retString += QChar(part);
-        }
-    }
-
-    return retString;
-}
-
 QString UnicodeEmoticon::key() const
 {
     return mKey;
@@ -77,7 +54,17 @@ void UnicodeEmoticon::setKey(const QString &key)
 bool UnicodeEmoticon::operator==(const UnicodeEmoticon &other) const
 {
     return (mAliases == other.aliases()) && (mIdentifier == other.identifier()) && (mUnicode == other.unicode()) && (mCategory == other.category())
-        && (mKey == other.key()) && (mOrder == other.order());
+        && (mKey == other.key()) && (mOrder == other.order()) && (mHasDiversityChildren == other.diversityChildren());
+}
+
+void UnicodeEmoticon::setDiversityChildren(bool b)
+{
+    mHasDiversityChildren = b;
+}
+
+bool UnicodeEmoticon::diversityChildren() const
+{
+    return mHasDiversityChildren;
 }
 
 int UnicodeEmoticon::order() const
@@ -92,7 +79,7 @@ void UnicodeEmoticon::setOrder(int order)
 
 void UnicodeEmoticon::setUnicode(const QString &unicode)
 {
-    mUnicode = escapeUnicodeEmoji(unicode);
+    mUnicode = EmoticonUnicodeUtils::escapeUnicodeEmoji(unicode);
 }
 
 QString UnicodeEmoticon::category() const
@@ -128,6 +115,7 @@ QDebug operator<<(QDebug d, const UnicodeEmoticon &t)
     d << "Aliases: " << t.aliases();
     d << "Order: " << t.order();
     d << "Key:" << t.key();
+    d << "DiversityChildren:" << t.diversityChildren();
     return d;
 }
 
