@@ -1,10 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "unicodeemoticonmanager.h"
+
 #include "textemoticonscore_debug.h"
 #include "unicodeemoticonparser.h"
 #include <KLocalizedString>
@@ -12,13 +13,14 @@
 #include <QFile>
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace TextEmoticonsCore;
 class TextEmoticonsCore::UnicodeEmoticonManagerPrivate
 {
 public:
     void loadUnicodeEmoji();
-    Q_REQUIRED_RESULT QString i18nUnicodeCategory(const QString &name) const;
-    QList<UnicodeEmoticon> mUnicodeEmojiList;
+    [[nodiscard]] QString i18nUnicodeCategory(const QString &name) const;
+    QList<UnicodeEmoticon> unicodeEmojiList;
 };
 
 void UnicodeEmoticonManagerPrivate::loadUnicodeEmoji()
@@ -32,29 +34,29 @@ void UnicodeEmoticonManagerPrivate::loadUnicodeEmoji()
     const QJsonDocument doc = QJsonDocument::fromJson(file.readAll());
 
     const QJsonObject obj = doc.object();
-    mUnicodeEmojiList = unicodeParser.parse(obj);
+    unicodeEmojiList = unicodeParser.parse(obj);
 }
 
 QString UnicodeEmoticonManagerPrivate::i18nUnicodeCategory(const QString &name) const
 {
     // Name "🚗"Category "travel", Name "🇿"Category "regional", Name "🏳️"Category "flags")
-    if (name == QLatin1String("symbols")) {
+    if (name == "symbols"_L1) {
         return i18n("Symbols");
-    } else if (name == QLatin1String("activity")) {
+    } else if (name == "activity"_L1) {
         return i18n("Activity");
-    } else if (name == QLatin1String("objects")) {
+    } else if (name == "objects"_L1) {
         return i18n("Objects");
-    } else if (name == QLatin1String("nature")) {
+    } else if (name == "nature"_L1) {
         return i18n("Nature");
-    } else if (name == QLatin1String("food")) {
+    } else if (name == "food"_L1) {
         return i18n("Food");
-    } else if (name == QLatin1String("people")) {
+    } else if (name == "people"_L1) {
         return i18n("People");
-    } else if (name == QLatin1String("travel")) {
+    } else if (name == "travel"_L1) {
         return i18n("Travel");
-    } else if (name == QLatin1String("regional")) {
+    } else if (name == "regional"_L1) {
         return i18n("Regional");
-    } else if (name == QLatin1String("flags")) {
+    } else if (name == "flags"_L1) {
         return i18n("Flags");
     } else {
         qCWarning(TEXTEMOTICONSCORE_LOG) << "Missing i18n translate " << name;
@@ -79,24 +81,24 @@ UnicodeEmoticonManager *UnicodeEmoticonManager::self()
 
 QList<UnicodeEmoticon> UnicodeEmoticonManager::unicodeEmojiList() const
 {
-    return d->mUnicodeEmojiList;
+    return d->unicodeEmojiList;
 }
 
 int UnicodeEmoticonManager::count() const
 {
-    return d->mUnicodeEmojiList.count();
+    return d->unicodeEmojiList.count();
 }
 
 QList<EmoticonCategory> UnicodeEmoticonManager::categories() const
 {
     QList<EmoticonCategory> categories;
     QSet<QString> seen;
-    for (const UnicodeEmoticon &emo : std::as_const(d->mUnicodeEmojiList)) {
+    for (const UnicodeEmoticon &emo : std::as_const(d->unicodeEmojiList)) {
         // Pick the first icon in each category
         const QString category = emo.category();
         if (!seen.contains(category)) {
             seen.insert(category);
-            if (category == QLatin1String("modifier")) { // pointless icons
+            if (category == "modifier"_L1) { // pointless icons
                 continue;
             }
             EmoticonCategory cat;
@@ -118,13 +120,13 @@ QList<UnicodeEmoticon> UnicodeEmoticonManager::emojisForCategory(const QString &
     auto hasRequestedCategory = [category](const UnicodeEmoticon &emo) {
         return emo.category() == category;
     };
-    std::copy_if(d->mUnicodeEmojiList.begin(), d->mUnicodeEmojiList.end(), std::back_inserter(result), hasRequestedCategory);
+    std::copy_if(d->unicodeEmojiList.begin(), d->unicodeEmojiList.end(), std::back_inserter(result), hasRequestedCategory);
     return result;
 }
 
 UnicodeEmoticon UnicodeEmoticonManager::unicodeEmoticonForEmoji(const QString &emojiIdentifier) const
 {
-    for (const UnicodeEmoticon &emo : d->mUnicodeEmojiList) {
+    for (const UnicodeEmoticon &emo : d->unicodeEmojiList) {
         if (emo.hasEmoji(emojiIdentifier)) {
             return emo;
         }
