@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,9 @@
 #include "emoticoncategorybuttons.h"
 #include "emoticonlistview.h"
 #include "emoticontexteditselector.h"
+#include "emoticontonecombobox.h"
 #include <QLineEdit>
+#include <QStandardPaths>
 #include <QTest>
 #include <QVBoxLayout>
 QTEST_MAIN(EmoticonTextEditSelectorTest)
@@ -16,6 +18,7 @@ QTEST_MAIN(EmoticonTextEditSelectorTest)
 EmoticonTextEditSelectorTest::EmoticonTextEditSelectorTest(QObject *parent)
     : QObject(parent)
 {
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 void EmoticonTextEditSelectorTest::shouldHaveDefaultValues()
@@ -37,6 +40,9 @@ void EmoticonTextEditSelectorTest::shouldHaveDefaultValues()
     QVERIFY(mSearchUnicodeLineEdit->text().isEmpty());
     QVERIFY(!mSearchUnicodeLineEdit->placeholderText().isEmpty());
 
+    auto emoticonTonComboBox = w.findChild<TextEmoticonsWidgets::EmoticonToneComboBox *>(QStringLiteral("emoticonToneComboBox"));
+    QVERIFY(emoticonTonComboBox);
+
     QVERIFY(!w.customEmojiSupport());
 }
 
