@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -79,9 +79,13 @@ bool EmoticonCategoryButtons::wasLoaded() const
 
 void EmoticonCategoryButtons::setCategories(const QList<TextEmoticonsCore::EmoticonCategory> &categories, bool hasCustomSupport)
 {
-    addButton(QStringLiteral("⌛️"), TextEmoticonsCore::EmoticonUnicodeUtils::recentIdentifier(), i18nc("Previously used emojis", "History"));
+    addButton(TextEmoticonsCore::EmoticonUnicodeUtils::recentName(),
+              TextEmoticonsCore::EmoticonUnicodeUtils::recentIdentifier(),
+              i18nc("Previously used emojis", "History"));
     if (hasCustomSupport) {
-        addButton(QStringLiteral("🖼️"), TextEmoticonsCore::EmoticonUnicodeUtils::customIdentifier(), i18nc("'Custom' is a category of emoji", "Custom"));
+        addButton(TextEmoticonsCore::EmoticonUnicodeUtils::customName(),
+                  TextEmoticonsCore::EmoticonUnicodeUtils::customIdentifier(),
+                  i18nc("'Custom' is a category of emoji", "Custom"));
     }
     for (const auto &cat : categories) {
         addButton(cat.name(), cat.category(), cat.i18nName());
