@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ public:
 
     void setCategories(const QList<TextEmoticonsCore::EmoticonCategory> &categories, bool hasCustomSupport);
 
-    Q_REQUIRED_RESULT bool wasLoaded() const;
+    [[nodiscard]] bool wasLoaded() const;
 
 Q_SIGNALS:
     void categorySelected(const QString &category);
@@ -34,7 +34,7 @@ protected:
     void wheelEvent(QWheelEvent *e) override;
 
 private:
-    void addButton(const QString &name, const QString &category, const QString &toolTip);
+    TEXTEMOTICONSWIDGETS_NO_EXPORT void addButton(const QString &name, const QString &category, const QString &toolTip);
     QHBoxLayout *const mMainLayout;
     QButtonGroup *const mButtonGroup;
     bool mWasLoaded = false;
