@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
   based on code from kopete
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -34,7 +34,7 @@ public:
     }
 
     void setCustomEmojiSupport(bool b);
-    Q_REQUIRED_RESULT bool customEmojiSupport() const;
+    [[nodiscard]] bool customEmojiSupport() const;
 
     QMenu *const emoticonMenu;
     EmoticonTextEditSelector *selector = nullptr;
@@ -52,7 +52,7 @@ bool EmoticonTextEditAction::EmoticonTextEditActionPrivate::customEmojiSupport()
 
 EmoticonTextEditAction::EmoticonTextEditAction(QObject *parent)
     : KActionMenu(i18n("Add Smiley"), parent)
-    , d(new EmoticonTextEditActionPrivate())
+    , d(new EmoticonTextEditActionPrivate)
 {
     delete menu();
     setMenu(d->emoticonMenu);
