@@ -1,12 +1,13 @@
 /*
-    SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "customemojiiconmanagerguitest.h"
-#include <QDebug>
+
 #include <QIcon>
+using namespace Qt::Literals::StringLiterals;
 CustomEmojiIconManagerGuiTest::CustomEmojiIconManagerGuiTest(QObject *parent)
     : TextEmoticonsCore::CustomEmojiIconManager(parent)
 {
@@ -18,11 +19,11 @@ CustomEmojiIconManagerGuiTest::~CustomEmojiIconManagerGuiTest()
 
 QIcon CustomEmojiIconManagerGuiTest::generateIcon(const QString &customIdentifier)
 {
-    if (customIdentifier == QStringLiteral(":custom1:")) {
+    if (customIdentifier == ":custom1:"_L1) {
         return QIcon::fromTheme(QStringLiteral("view-refresh"));
-    } else if (customIdentifier == QStringLiteral(":custom2:")) {
+    } else if (customIdentifier == ":custom2:"_L1) {
         return QIcon::fromTheme(QStringLiteral("lock"));
-    } else if (customIdentifier == QStringLiteral(":gif1:")) {
+    } else if (customIdentifier == ":gif1:"_L1) {
         return {};
     }
     return {};
@@ -30,7 +31,7 @@ QIcon CustomEmojiIconManagerGuiTest::generateIcon(const QString &customIdentifie
 
 QString CustomEmojiIconManagerGuiTest::fileName(const QString &customIdentifier)
 {
-    if (customIdentifier == QStringLiteral(":gif1:")) {
+    if (customIdentifier == ":gif1:"_L1) {
         return QStringLiteral(":/gif1");
     }
     return {};
