@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,7 @@
 #include <KStatefulBrush>
 
 #include <KLocalizedString>
-#include <KStandardAction>
+#include <KStandardActions>
 #include <QDesktopServices>
 
 #include <KColorScheme>
@@ -25,9 +25,6 @@ GrammarResultTextEdit::GrammarResultTextEdit(QWidget *parent)
 {
     setReadOnly(true);
     setAcceptRichText(false);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(qApp, &QApplication::paletteChanged, this, &GrammarResultTextEdit::generalPaletteChanged);
-#endif
     generalPaletteChanged();
 }
 
@@ -57,11 +54,9 @@ void GrammarResultTextEdit::paintEvent(QPaintEvent *event)
 
 bool GrammarResultTextEdit::event(QEvent *ev)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (ev->type() == QEvent::ApplicationPaletteChange) {
         generalPaletteChanged();
     }
-#endif
     return QTextEdit::event(ev);
 }
 
@@ -115,10 +110,10 @@ void GrammarResultTextEdit::contextMenuEvent(QContextMenuEvent *event)
         QAction *checkAgainAct = popup->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Check Again"));
         connect(checkAgainAct, &QAction::triggered, this, &GrammarResultTextEdit::checkAgain);
         popup->addSeparator();
-        QAction *configureAct = popup->addAction(QIcon::fromTheme(QStringLiteral("settings-configure")), i18n("Configure..."));
+        QAction *configureAct = popup->addAction(QIcon::fromTheme(QStringLiteral("settings-configure")), i18n("Configure…"));
         connect(configureAct, &QAction::triggered, this, &GrammarResultTextEdit::configure);
         popup->addSeparator();
-        QAction *closeAct = KStandardAction::close(this, &GrammarResultTextEdit::closeChecker, this);
+        QAction *closeAct = KStandardActions::close(this, &GrammarResultTextEdit::closeChecker, this);
         closeAct->setShortcut({});
         popup->addAction(closeAct);
         popup->exec(event->globalPos());
