@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -46,6 +46,12 @@ void GrammalecteConfigWidgetTest::shouldHaveDefaultValue()
     QVERIFY(mGrammalectePath);
     QVERIFY(mGrammalectePath->path().isEmpty());
 
+    auto grammalecteInfoDownload = generalWidget->findChild<QLabel *>(QStringLiteral("grammalecteInfoDownload"));
+    QVERIFY(grammalecteInfoDownload);
+    QVERIFY(!grammalecteInfoDownload->text().isEmpty());
+    QVERIFY(grammalecteInfoDownload->openExternalLinks());
+    QCOMPARE(grammalecteInfoDownload->textFormat(), Qt::RichText);
+
     auto mStackedWidget = mTab->findChild<QStackedWidget *>(QStringLiteral("stackedwidget"));
     QVERIFY(mStackedWidget);
     auto mScrollArea = mStackedWidget->findChild<QScrollArea *>(QStringLiteral("scrollarea"));
@@ -64,7 +70,7 @@ void GrammalecteConfigWidgetTest::shouldHaveDefaultValue()
     QVERIFY(!label->text().isEmpty());
     auto buttonReloadSettings = mReloadSettingsWidget->findChild<QToolButton *>(QStringLiteral("buttonReloadSettings"));
     QVERIFY(buttonReloadSettings);
-    QVERIFY(!buttonReloadSettings->icon().isNull());
+    // QVERIFY(!buttonReloadSettings->icon().isNull());
 }
 
 #include "moc_grammalecteconfigwidgettest.cpp"
