@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -59,7 +59,7 @@ void GrammalecteConfigWidget::slotGetSettingsError()
     if (!mDisableDialogBox) {
         KMessageBox::error(this,
                            i18n("Impossible to get options. Please verify that you have grammalected installed."),
-                           i18n("Error during Extracting Options"));
+                           i18nc("@title:window", "Error during Extracting Options"));
     }
 }
 
@@ -108,14 +108,15 @@ QWidget *GrammalecteConfigWidget::addGrammarTab()
     reloadSettingsLayout->setObjectName(QStringLiteral("reloadSettingsLayout"));
     auto horizontallayout = new QHBoxLayout;
     reloadSettingsLayout->addLayout(horizontallayout);
-    auto label = new QLabel(i18n("Press Button for Reloading Settings"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Press Button for Reloading Settings"), this);
+    label->setTextFormat(Qt::PlainText);
     label->setObjectName(QStringLiteral("label"));
     horizontallayout->addWidget(label);
 
     auto buttonReloadSettings = new QToolButton(this);
     buttonReloadSettings->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     buttonReloadSettings->setObjectName(QStringLiteral("buttonReloadSettings"));
-    buttonReloadSettings->setToolTip(i18n("Reload Settings"));
+    buttonReloadSettings->setToolTip(i18nc("@info:tooltip", "Reload Settings"));
     horizontallayout->addWidget(buttonReloadSettings);
     connect(buttonReloadSettings, &QToolButton::clicked, this, &GrammalecteConfigWidget::loadGrammarSettings);
 
@@ -136,9 +137,17 @@ QWidget *GrammalecteConfigWidget::addGeneralTab()
 
     mGrammalectePath = new TextGrammarCheck::GrammalecteUrlRequesterWidget(this);
     mGrammalectePath->setObjectName(QStringLiteral("grammalectepath"));
-    mGrammalectePath->setPlaceholderText(i18n("Add full 'grammalecte-cli.py' path"));
+    mGrammalectePath->setPlaceholderText(i18nc("@info:placeholder", "Add full 'grammalecte-cli.py' path"));
+
     lay->addRow(i18n("Grammalecte Path:"), mGrammalectePath);
 
+    auto grammalecteInfoDownload = new QLabel(this);
+    grammalecteInfoDownload->setObjectName(QStringLiteral("grammalecteInfoDownload"));
+    grammalecteInfoDownload->setTextFormat(Qt::RichText);
+    grammalecteInfoDownload->setOpenExternalLinks(true);
+    grammalecteInfoDownload->setText(i18n("Grammalecte can be found <a href=\"https://grammalecte.net/#download\">here</a>. Download it and extract it."));
+    lay->addWidget(grammalecteInfoDownload);
+
     return w;
 }
 
