@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -70,7 +70,7 @@ void GrammalecteResultWidget::slotError(GrammalecteResultJob::ErrorType error)
         break;
     }
     if (!str.isEmpty()) {
-        KMessageBox::error(this, str, i18n("Grammalecte error"));
+        KMessageBox::error(this, str, i18nc("@title:window", "Grammalecte error"));
     }
 }
 
