@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -46,7 +46,7 @@ LanguageToolConfigDialog::~LanguageToolConfigDialog()
 
 void LanguageToolConfigDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
@@ -54,7 +54,7 @@ void LanguageToolConfigDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(500, 300));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myConfigGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
