@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 #include "languagetoolcombobox.h"
 #include "languagetoolmanager.h"
 #include "languagetoolupdatecombobox.h"
-// #include "textgrammarcheck_debug.h"
+#include <KLineEditEventHandler>
 #include <KLocalizedString>
 
 #include <QCheckBox>
@@ -19,9 +19,9 @@
 using namespace TextGrammarCheck;
 LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
     : QWidget(parent)
-    , mUseLocalInstance(new QCheckBox(i18n("Use Local Instance"), this))
+    , mUseLocalInstance(new QCheckBox(i18nc("@option:check", "Use Local Instance"), this))
     , mInstancePath(new QLineEdit(this))
-    , mInstancePathLabel(new QLabel(i18n("Instance Path:"), this))
+    , mInstancePathLabel(new QLabel(i18nc("@label:textbox", "Instance Path:"), this))
     , mLanguageToolCombobox(new LanguageToolComboBox(this))
     , mLanguageToolUpdateCombobox(new LanguageToolUpdateComboBox(this))
 {
@@ -37,11 +37,13 @@ LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
     instanceLayout->setContentsMargins({});
     mInstancePathLabel->setObjectName(QStringLiteral("instancepath"));
     mInstancePathLabel->setEnabled(false);
+    mInstancePathLabel->setTextFormat(Qt::PlainText);
     instanceLayout->addWidget(mInstancePathLabel);
 
     mInstancePath->setObjectName(QStringLiteral("instancepath"));
     mInstancePath->setEnabled(false);
     mInstancePath->setClearButtonEnabled(true);
+    KLineEditEventHandler::catchReturnKey(mInstancePath);
     instanceLayout->addWidget(mInstancePath);
     mainLayout->addLayout(instanceLayout);
 
@@ -49,7 +51,8 @@ LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
 
     auto languageLayout = new QHBoxLayout;
     languageLayout->setObjectName(QStringLiteral("languagelayout"));
-    auto languageLabel = new QLabel(i18n("Language:"), this);
+    auto languageLabel = new QLabel(i18nc("@label:textbox", "Language:"), this);
+    languageLabel->setTextFormat(Qt::PlainText);
     languageLabel->setObjectName(QStringLiteral("languageLabel"));
     languageLayout->addWidget(languageLabel);
 
@@ -61,7 +64,10 @@ LanguageToolConfigWidget::LanguageToolConfigWidget(QWidget *parent)
     auto refreshButton = new QToolButton(this);
     refreshButton->setObjectName(QStringLiteral("refreshbutton"));
     refreshButton->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
-    refreshButton->setToolTip(i18n("Refresh"));
+    refreshButton->setToolTip(i18nc("@info:tooltip", "Refresh"));
+    if (!LanguageToolManager::self()->allowToGetListOfLanguages()) {
+        refreshButton->setVisible(false);
+    }
     languageLayout->addWidget(refreshButton);
     connect(refreshButton, &QToolButton::clicked, this, [this]() {
         if (LanguageToolManager::self()->allowToGetListOfLanguages()) {
