@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -57,7 +57,7 @@ void LanguageToolResultWidget::slotCheckGrammarFinished(const QString &result)
 
 void LanguageToolResultWidget::slotError(const QString &str)
 {
-    KMessageBox::error(this, i18n("An error was reported: %1", str), i18n("Failed to check grammar."));
+    KMessageBox::error(this, i18n("An error was reported: %1", str), i18nc("@title:window", "Failed to check grammar."));
 }
 
 void LanguageToolResultWidget::addExtraWidget()
@@ -73,7 +73,7 @@ void LanguageToolResultWidget::addExtraWidget()
     recheckBtn->setObjectName(QStringLiteral("recheck-button"));
     recheckBtn->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
     recheckBtn->setIconSize(QSize(16, 16));
-    recheckBtn->setToolTip(i18n("Check"));
+    recheckBtn->setToolTip(i18nc("@info:tooltip", "Check"));
     recheckBtn->setAutoRaise(true);
     extraWidgetLayout->addWidget(recheckBtn);
 
