@@ -1,17 +1,19 @@
 /*
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "translatorutil.h"
+
 #include "texttranslator_debug.h"
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <QComboBox>
-using namespace TextTranslator;
 
+using namespace Qt::Literals::StringLiterals;
+using namespace TextTranslator;
 TranslatorUtil::TranslatorUtil() = default;
 
 QMap<TranslatorUtil::Language, QString> TranslatorUtil::translatedLanguages()
@@ -226,23 +228,23 @@ QString TranslatorUtil::searchI18nFromLanguage(const QString &langCode)
 
 TranslatorUtil::Language TranslatorUtil::stringToLanguage(const QString &str)
 {
-    if (str == QStringLiteral("en")) {
+    if (str == "en"_L1) {
         return TranslatorUtil::en;
-    } else if (str == QStringLiteral("fr")) {
+    } else if (str == "fr"_L1) {
         return TranslatorUtil::fr;
-    } else if (str == QStringLiteral("es")) {
+    } else if (str == "es"_L1) {
         return TranslatorUtil::es;
-    } else if (str == QStringLiteral("pl")) {
+    } else if (str == "pl"_L1) {
         return TranslatorUtil::pl;
-    } else if (str == QStringLiteral("de")) {
+    } else if (str == "de"_L1) {
         return TranslatorUtil::de;
-    } else if (str == QStringLiteral("cs")) {
+    } else if (str == "cs"_L1) {
         return TranslatorUtil::cs;
-    } else if (str == QStringLiteral("bg")) {
+    } else if (str == "bg"_L1) {
         return TranslatorUtil::bg;
-    } else if (str == QStringLiteral("et")) {
+    } else if (str == "et"_L1) {
         return TranslatorUtil::et;
-        //    } else if (str == QStringLiteral("nn")) {
+        //    } else if (str == "nn"_L1) {
         //        return TranslatorUtil::nn;
     } else {
         qCWarning(TEXTTRANSLATOR_LOG) << " Impossible to find TranslatorUtil::Language for " << str;
