@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,11 +17,7 @@
 #include <QTreeView>
 #include <QVBoxLayout>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-#include <TextAddonsWidgets/LineEditCatchReturnKey>
-#else
 #include <KLineEditEventHandler>
-#endif
 
 BergamotEngineLanguageWidget::BergamotEngineLanguageWidget(QWidget *parent)
     : QWidget{parent}
@@ -48,14 +44,10 @@ BergamotEngineLanguageWidget::BergamotEngineLanguageWidget(QWidget *parent)
 
     mSearchLineEdit->setObjectName(QStringLiteral("mSearchLineEdit"));
     vboxLayout->addWidget(mSearchLineEdit);
-    mSearchLineEdit->setPlaceholderText(i18n("Search..."));
+    mSearchLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search…"));
     mSearchLineEdit->setClearButtonEnabled(true);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-    new TextAddonsWidgets::LineEditCatchReturnKey(mSearchLineEdit, this);
-#else
     KLineEditEventHandler::catchReturnKey(mSearchLineEdit);
-#endif
 
     mTreeView->setObjectName(QStringLiteral("mTreeView"));
     connect(ManagerModelTranslator::self(), &ManagerModelTranslator::errorText, this, &BergamotEngineLanguageWidget::slotError);
@@ -71,6 +63,7 @@ BergamotEngineLanguageWidget::BergamotEngineLanguageWidget(QWidget *parent)
     }
 
     mTranslatorProxyModel->setSortCaseSensitivity(Qt::CaseInsensitive);
+    mTranslatorProxyModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
     mTranslatorProxyModel->setSourceModel(mTranslatorModel);
     mTreeView->setModel(mTranslatorProxyModel);
     mTreeView->setRootIsDecorated(false);
@@ -101,8 +94,8 @@ BergamotEngineLanguageWidget::BergamotEngineLanguageWidget(QWidget *parent)
     deleteLanguage->setObjectName(QStringLiteral("downLoadLanguage"));
     buttonLayout->addWidget(deleteLanguage);
 
-    auto updateListLanguage = new QPushButton(i18n("Update List"), this);
-    updateListLanguage->setToolTip(i18n("Update list of languages from network"));
+    auto updateListLanguage = new QPushButton(i18nc("@action:button", "Update List"), this);
+    updateListLanguage->setToolTip(i18nc("@info:tooltip", "Update list of languages from network"));
     updateListLanguage->setObjectName(QStringLiteral("updateListLanguage"));
     buttonLayout->addWidget(updateListLanguage);
     buttonLayout->addStretch(1); // spacer
