@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,8 +8,6 @@
 #include "extractlanguagejob.h"
 #include "libbergamot_debug.h"
 #include <KLocalizedString>
-#include <QCryptographicHash>
-#include <QFileInfo>
 #include <QNetworkReply>
 #include <QNetworkRequest>
 #include <QTemporaryFile>
