@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,10 +15,10 @@ public:
     explicit ExtractLanguageJob(QObject *parent = nullptr);
     ~ExtractLanguageJob() override;
 
-    Q_REQUIRED_RESULT bool canStart() const;
+    [[nodiscard]] bool canStart() const;
     void start();
 
-    Q_REQUIRED_RESULT QString source() const;
+    [[nodiscard]] QString source() const;
     void setSource(const QString &newSource);
 
 Q_SIGNALS:
