@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -71,7 +71,7 @@ void ManagerModelTranslator::loadModelList(const QString &fileName)
 void ManagerModelTranslator::parseListModel(const QJsonObject &obj)
 {
     mTranslators.clear();
-    const QJsonArray arrays = obj[QStringLiteral("models")].toArray();
+    const QJsonArray arrays = obj[QLatin1String("models")].toArray();
     for (const QJsonValue &current : arrays) {
         if (current.type() == QJsonValue::Object) {
             Translator translator;
