@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -7,15 +7,15 @@
 */
 
 #include "translation.h"
-#include <bergamot-translator/src/translator/response.h>
+#include <slimt/Response.hh>
 
 Translation::Translation()
     : mResponse(nullptr)
 {
 }
 
-Translation::Translation(marian::bergamot::Response &&response)
-    : mResponse(std::make_shared<marian::bergamot::Response>(std::move(response)))
+Translation::Translation(slimt::Response &&response)
+    : mResponse(std::make_shared<slimt::Response>(std::move(response)))
 {
 }
 
