@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -10,16 +10,12 @@
 #include "libbergamot_export.h"
 #include <QMetaType>
 #include <QString>
-#include <QVector>
 #include <memory>
 
-namespace marian
-{
-namespace bergamot
+namespace slimt
 {
 class Response;
 }
-}
 
 /**
  * Wrapper around a translation response from the bergamot service. Hides that
@@ -30,7 +26,7 @@ class LIBBERGAMOT_EXPORT Translation
 {
 public:
     Translation();
-    Translation(marian::bergamot::Response &&response);
+    Translation(slimt::Response &&response);
 
     /**
      * Bool operator to check whether this is an initialised translation or just
@@ -44,12 +40,12 @@ public:
     /**
      * Translation result
      */
-    Q_REQUIRED_RESULT QString translation() const;
+    [[nodiscard]] QString translation() const;
 
 private:
     // Note: I would have liked unique_ptr, but that does not go well with
     // passing Translation objects through Qt signals/slots.
-    std::shared_ptr<marian::bergamot::Response> mResponse;
+    std::shared_ptr<slimt::Response> mResponse;
 };
 
 Q_DECLARE_METATYPE(Translation)
