@@ -1,10 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "googleengineplugin.h"
+
 #include "googletranslator_debug.h"
 #include <KLocalizedString>
 #include <QJsonDocument>
@@ -12,9 +13,11 @@
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#include <QRegularExpression>
 #include <QUrlQuery>
 #include <TextTranslator/TranslatorEngineAccessManager>
 
+using namespace Qt::Literals::StringLiterals;
 GoogleEnginePlugin::GoogleEnginePlugin(QObject *parent)
     : TextTranslator::TranslatorEnginePlugin(parent)
 {
@@ -57,7 +60,7 @@ void GoogleEnginePlugin::translate()
 
 QString GoogleEnginePlugin::languageCode(const QString &langStr)
 {
-    if (langStr == QLatin1String("iw")) {
+    if (langStr == "iw"_L1) {
         return QStringLiteral("iw");
     }
     return langStr;
