@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,11 +14,7 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <QPointer>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 
 LibreTranslateEngineClient::LibreTranslateEngineClient(QObject *parent)
     : TextTranslator::TranslatorEngineClient{parent}
