@@ -1,26 +1,22 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "libretranslateengineconfigurewidget.h"
+#include <KLineEditEventHandler>
 #include <KLocalizedString>
 #include <QCheckBox>
 #include <QCompleter>
 #include <QFormLayout>
 #include <QLineEdit>
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-#include <TextAddonsWidgets/LineEditCatchReturnKey>
-#else
-#include <KLineEditEventHandler>
-#endif
 
 LibreTranslateEngineConfigureWidget::LibreTranslateEngineConfigureWidget(QWidget *parent)
     : QWidget{parent}
     , mServerUrl(new QLineEdit(this))
     , mApiKey(new QLineEdit(this))
-    , mRequiredApiKey(new QCheckBox(i18n("Server required Api Key"), this))
+    , mRequiredApiKey(new QCheckBox(i18nc("@option:check", "Server required Api Key"), this))
 {
     auto mainLayout = new QFormLayout(this);
     mainLayout->setContentsMargins({});
@@ -48,13 +44,8 @@ LibreTranslateEngineConfigureWidget::LibreTranslateEngineConfigureWidget(QWidget
         QStringLiteral("https://lt.vern.cc"),
     };
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-    new TextAddonsWidgets::LineEditCatchReturnKey(mApiKey, this);
-    new TextAddonsWidgets::LineEditCatchReturnKey(mServerUrl, this);
-#else
     KLineEditEventHandler::catchReturnKey(mApiKey);
     KLineEditEventHandler::catchReturnKey(mServerUrl);
-#endif
 
     auto completer = new QCompleter(listServer, this);
     completer->setCaseSensitivity(Qt::CaseInsensitive);
