@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -8,6 +8,7 @@
 */
 
 #include "libretranslateengineplugin.h"
+
 #include "libretranslateengineutil.h"
 #include "libretranslatetranslator_debug.h"
 
@@ -17,12 +18,9 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <TextTranslator/TranslatorEngineAccessManager>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
 #include <qt6keychain/keychain.h>
-#endif
 
+using namespace Qt::Literals::StringLiterals;
 LibreTranslateEnginePlugin::LibreTranslateEnginePlugin(QObject *parent)
     : TextTranslator::TranslatorEnginePlugin(parent)
 {
@@ -62,7 +60,7 @@ void LibreTranslateEnginePlugin::translateText()
     }
     const auto url = QUrl(QStringLiteral("%1/translate").arg(mServerUrl));
     QNetworkRequest request;
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded"_L1);
     request.setUrl(url);
 
     qCDebug(TRANSLATOR_LIBRETRANSLATE_LOG) << " url " << url;
