@@ -1,11 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "lingvaengineclienttest.h"
 #include "../lingvaengineclient.h"
+#include "translator/translatorengineplugin.h"
 #include <QTest>
 QTEST_MAIN(LingvaEngineClientTest)
 
@@ -18,7 +19,9 @@ void LingvaEngineClientTest::shouldHaveDefaultValues()
 {
     LingvaEngineClient client;
     QCOMPARE(client.name(), QStringLiteral("lingva"));
-    QVERIFY(client.createTranslator());
+    auto plugin = client.createTranslator();
+    QVERIFY(plugin);
+    delete plugin;
     QVERIFY(!client.translatedName().isEmpty());
     QVERIFY(!client.supportedFromLanguages().isEmpty());
     QVERIFY(!client.supportedToLanguages().isEmpty());
