@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ public:
     explicit LingvaEngineDialog(QWidget *parent = nullptr);
     ~LingvaEngineDialog() override;
 
-    Q_REQUIRED_RESULT QString serverUrl() const;
+    [[nodiscard]] QString serverUrl() const;
 
     void setServerUrl(const QString &serverUrl);
 
