@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,12 +31,22 @@ TextTranslator::TranslatorEnginePlugin *YandexEngineClient::createTranslator()
     return new YandexEnginePlugin();
 }
 
-QMap<TextTranslator::TranslatorUtil::Language, QString> YandexEngineClient::supportedLanguages()
+QMap<TextTranslator::TranslatorUtil::Language, QString> YandexEngineClient::supportedFromLanguages()
 {
-    if (mLanguages.isEmpty()) {
-        mLanguages = fillLanguages();
+    if (mFromLanguages.isEmpty()) {
+        mFromLanguages = fillLanguages();
     }
-    return mLanguages;
+    return mFromLanguages;
+}
+
+QMap<TextTranslator::TranslatorUtil::Language, QString> YandexEngineClient::supportedToLanguages()
+{
+    return supportedFromLanguages();
+}
+
+TextTranslator::TranslatorEngineClient::EngineType YandexEngineClient::engineType() const
+{
+    return TextTranslator::TranslatorEngineClient::Network;
 }
 
 bool YandexEngineClient::isSupported(TextTranslator::TranslatorUtil::Language lang) const
