@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ TranslatorEngineAccessManager *TranslatorEngineAccessManager::self()
     return &s_self;
 }
 
-QNetworkAccessManager *TranslatorEngineAccessManager::networkManager()
+QNetworkAccessManager *TranslatorEngineAccessManager::networkManager() const
 {
     return mNetworkAccessManager;
 }
