@@ -1,15 +1,17 @@
 /*
-  SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "translatorengineloader.h"
+
 #include "texttranslator_debug.h"
 #include "translatorengineclient.h"
 #include <QCoreApplication>
 #include <QDir>
 #include <QPluginLoader>
+using namespace Qt::Literals::StringLiterals;
 using namespace TextTranslator;
 class TextTranslator::TranslatorEngineLoaderPrivate
 {
@@ -36,7 +38,7 @@ TranslatorEngineLoader::~TranslatorEngineLoader() = default;
 void TranslatorEngineLoader::loadPlugins()
 {
     const QStringList libPaths = QCoreApplication::libraryPaths();
-    const QString pathSuffix(QStringLiteral("/kf" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/translator/"));
+    const QString pathSuffix(QStringLiteral("/kf6/translator/"));
     for (const QString &libPath : libPaths) {
         QDir dir(libPath + pathSuffix);
         if (!dir.exists()) {
@@ -54,7 +56,7 @@ void TranslatorEngineLoader::loadPlugins()
 void TranslatorEngineLoader::loadPlugin(const QString &pluginPath)
 {
     QPluginLoader plugin(pluginPath);
-    const QString pluginIID = plugin.metaData()[QStringLiteral("IID")].toString();
+    const QString pluginIID = plugin.metaData()["IID"_L1].toString();
     if (!pluginIID.isEmpty()) {
         if (d->loadedPlugins.contains(pluginIID)) {
             qCDebug(TEXTTRANSLATOR_LOG) << "Skipping already loaded" << pluginPath;
@@ -103,7 +105,7 @@ QMap<QString, QString> TranslatorEngineLoader::translatorEngineInfos() const
     QHashIterator<QString, TranslatorEngineClient *> i(d->translatorClients);
     while (i.hasNext()) {
         i.next();
-        map.insert(i.key(), i.value()->translatedName());
+        map.insert(i.key(), i.value()->translatedName() + QStringLiteral(" (%1)").arg(TranslatorEngineClient::convertEngineType(i.value()->engineType())));
     }
     return map;
 }
