@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ using namespace TextTranslator;
 TranslatorConfigureComboWidget::TranslatorConfigureComboWidget(QWidget *parent)
     : QWidget{parent}
     , mEngineComboBox(new QComboBox(this))
-    , mConfigureEngine(new QToolButton(parent))
+    , mConfigureEngine(new QToolButton(this))
 {
     auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
