@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,8 +36,9 @@ TranslatorConfigureWidget::TranslatorConfigureWidget(QWidget *parent)
     hboxLayout->setContentsMargins({});
     mainLayout->addLayout(hboxLayout);
 
-    auto label = new QLabel(i18n("Engine:"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Engine:"), this);
     label->setObjectName(QStringLiteral("label"));
+    label->setTextFormat(Qt::PlainText);
     hboxLayout->addWidget(label);
     hboxLayout->addWidget(d->mEngineConfigureComboWidget);
 }
