@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,8 +20,8 @@ TranslatorMenu::TranslatorMenu(QObject *parent)
     , mMenu(new QMenu)
 {
     mMenu->setObjectName(QStringLiteral("menu"));
-    mMenu->setTitle(i18n("Translate..."));
-    mMenu->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-locale")));
+    mMenu->setTitle(i18n("Translate…"));
+    mMenu->setIcon(QIcon::fromTheme(QStringLiteral("translate")));
     updateMenu();
 }
 
