@@ -1,11 +1,12 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "translatorwidget.h"
+
 #include "texttranslator_debug.h"
 #include "translator/misc/translatorutil.h"
 #include "translator/networkmanager.h"
@@ -29,12 +30,12 @@
 #include <QKeyEvent>
 #include <QLabel>
 #include <QMimeData>
-#include <QPainter>
 #include <QShortcut>
 #include <QSplitter>
 #include <QToolButton>
 #include <QVBoxLayout>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace TextTranslator;
 namespace
 {
@@ -60,6 +61,7 @@ public:
     QComboBox *toCombobox = nullptr;
     QPushButton *translate = nullptr;
     QPushButton *clear = nullptr;
+    QToolButton *closeBtn = nullptr;
     QLabel *engineNameLabel = nullptr;
     TextTranslator::TranslatorEngineClient *translatorClient = nullptr;
     TextTranslator::TranslatorEnginePlugin *translatorPlugin = nullptr;
@@ -157,15 +159,15 @@ void TranslatorWidget::writeConfig()
         myGroup.writeEntry("ToLanguage", d->toCombobox->itemData(d->toCombobox->currentIndex()).toString());
         myGroup.sync();
     }
-    KConfigGroup myGroupUi(KSharedConfig::openStateConfig(), QLatin1String(myTranslatorWidgetConfigGroupName));
+    KConfigGroup myGroupUi(KSharedConfig::openStateConfig(), QLatin1StringView(myTranslatorWidgetConfigGroupName));
     myGroupUi.writeEntry("mainSplitter", d->splitter->sizes());
     myGroupUi.sync();
 }
 
 void TranslatorWidget::readConfig()
 {
-    KConfigGroup myGroupUi(KSharedConfig::openStateConfig(), QLatin1String(myTranslatorWidgetConfigGroupName));
-    const QList<int> size = {100, 400};
+    KConfigGroup myGroupUi(KSharedConfig::openStateConfig(), QLatin1StringView(myTranslatorWidgetConfigGroupName));
+    const QList<int> size = {100, 100};
     d->splitter->setSizes(myGroupUi.readEntry("mainSplitter", size));
 
     KConfigGroup myGroup(KSharedConfig::openConfig(), QStringLiteral("General"));
@@ -188,7 +190,7 @@ void TranslatorWidget::readConfig()
     if (indexTo != -1) {
         d->toCombobox->setCurrentIndex(indexTo);
     }
-    d->invert->setEnabled(from != QLatin1String("auto"));
+    d->invert->setEnabled(from != "auto"_L1);
 }
 
 void TranslatorWidget::loadEngineSettings()
@@ -201,23 +203,30 @@ void TranslatorWidget::loadEngineSettings()
 void TranslatorWidget::init()
 {
     auto layout = new QVBoxLayout(this);
+    layout->setSpacing(0);
     layout->setContentsMargins({});
+
     auto hboxLayout = new QHBoxLayout;
-    hboxLayout->setContentsMargins({});
-    auto closeBtn = new QToolButton(this);
-    closeBtn->setObjectName(QStringLiteral("close-button"));
-    closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
-    closeBtn->setIconSize(QSize(16, 16));
-    closeBtn->setToolTip(i18n("Close"));
+    hboxLayout->setSpacing(style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
+    hboxLayout->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                                   style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                                   style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                                   style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+    d->closeBtn = new QToolButton(this);
+    d->closeBtn->setObjectName(QStringLiteral("close-button"));
+    d->closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
+    d->closeBtn->setIconSize(QSize(16, 16));
+    d->closeBtn->setToolTip(i18nc("@info:tooltip", "Close"));
 
 #ifndef QT_NO_ACCESSIBILITY
-    closeBtn->setAccessibleName(i18n("Close"));
+    d->closeBtn->setAccessibleName(i18n("Close"));
 #endif
-    closeBtn->setAutoRaise(true);
-    hboxLayout->addWidget(closeBtn);
-    connect(closeBtn, &QToolButton::clicked, this, &TranslatorWidget::slotCloseWidget);
+    d->closeBtn->setAutoRaise(true);
+    hboxLayout->addWidget(d->closeBtn);
+    connect(d->closeBtn, &QToolButton::clicked, this, &TranslatorWidget::slotCloseWidget);
 
     auto label = new QLabel(i18nc("Translate from language", "From:"), this);
+    label->setTextFormat(Qt::PlainText);
     hboxLayout->addWidget(label);
     d->fromCombobox = new QComboBox(this);
     d->fromCombobox->setMinimumWidth(50);
@@ -225,6 +234,7 @@ void TranslatorWidget::init()
     hboxLayout->addWidget(d->fromCombobox);
 
     label = new QLabel(i18nc("Translate to language", "To:"), this);
+    label->setTextFormat(Qt::PlainText);
     hboxLayout->addWidget(label);
     d->toCombobox = new QComboBox(this);
     d->toCombobox->setMinimumWidth(50);
@@ -241,7 +251,7 @@ void TranslatorWidget::init()
     connect(d->invert, &QPushButton::clicked, this, &TranslatorWidget::slotInvertLanguage);
     hboxLayout->addWidget(d->invert);
 
-    d->clear = new QPushButton(i18n("Clear"), this);
+    d->clear = new QPushButton(i18nc("@action:button", "Clear"), this);
     d->clear->setObjectName(QStringLiteral("clear-button"));
 #ifndef QT_NO_ACCESSIBILITY
     d->clear->setAccessibleName(i18n("Clear"));
@@ -249,7 +259,7 @@ void TranslatorWidget::init()
     connect(d->clear, &QPushButton::clicked, this, &TranslatorWidget::slotClear);
     hboxLayout->addWidget(d->clear);
 
-    d->translate = new QPushButton(i18n("Translate"), this);
+    d->translate = new QPushButton(i18nc("@action:button", "Translate"), this);
     d->translate->setObjectName(QStringLiteral("translate-button"));
 #ifndef QT_NO_ACCESSIBILITY
     d->translate->setAccessibleName(i18n("Translate"));
@@ -259,7 +269,7 @@ void TranslatorWidget::init()
     connect(d->translate, &QPushButton::clicked, this, &TranslatorWidget::slotTranslate);
 
     if (!qEnvironmentVariableIsEmpty("TRANSLATING_DEBUGGING")) {
-        auto debugButton = new QPushButton(i18n("Debug"));
+        auto debugButton = new QPushButton(i18nc("@action:button", "Debug"), this);
         hboxLayout->addWidget(debugButton);
         connect(debugButton, &QPushButton::clicked, this, &TranslatorWidget::slotDebug);
     }
@@ -277,7 +287,7 @@ void TranslatorWidget::init()
     configureButton->setObjectName(QStringLiteral("configure_button"));
     configureButton->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
     configureButton->setIconSize(QSize(16, 16));
-    configureButton->setToolTip(i18n("Configure"));
+    configureButton->setToolTip(i18nc("@info:tooltip", "Configure"));
     connect(configureButton, &QToolButton::clicked, this, [this]() {
         TranslatorConfigureDialog dlg(this);
         if (dlg.exec()) {
@@ -288,6 +298,10 @@ void TranslatorWidget::init()
 
     layout->addLayout(hboxLayout);
 
+    separator = new KSeparator(this);
+    separator->setOrientation(Qt::Horizontal);
+    layout->addWidget(separator);
+
     d->splitter = new QSplitter;
     d->splitter->setChildrenCollapsible(false);
     d->inputText = new TranslatorTextEdit(this);
@@ -352,9 +366,10 @@ void TranslatorWidget::switchEngine()
 void TranslatorWidget::updatePlaceHolder()
 {
     if (d->translatorClient->engineType() == TextTranslator::TranslatorEngineClient::Network) {
-        d->inputText->setPlaceholderText(i18n("Drag text that you want to translate. (Be careful text will be send to external Server)."));
+        d->inputText->setPlaceholderText(
+            i18nc("@info:placeholder", "Drag text that you want to translate. (Be careful text will be send to external Server)."));
     } else {
-        d->inputText->setPlaceholderText(i18n("Drag text that you want to translate."));
+        d->inputText->setPlaceholderText(i18nc("@info:placeholder", "Drag text that you want to translate."));
     }
 }
 
@@ -372,7 +387,7 @@ void TranslatorWidget::slotTextChanged()
 void TranslatorWidget::slotFromLanguageChanged(int index, bool initialize)
 {
     const QString lang = d->fromCombobox->itemData(index).toString();
-    d->invert->setEnabled(lang != QLatin1String("auto"));
+    d->invert->setEnabled(lang != "auto"_L1);
     const QString to = d->toCombobox->itemData(d->toCombobox->currentIndex()).toString();
 
     // Get "from" language code for generating "to" language list
@@ -403,7 +418,7 @@ void TranslatorWidget::slotTranslate()
         return;
     }
     if (!TextTranslator::NetworkManager::self()->isOnline()) {
-        KMessageBox::information(this, i18n("No network connection detected, we cannot translate text."), i18n("No network"));
+        KMessageBox::information(this, i18n("No network connection detected, we cannot translate text."), i18nc("@title:window", "No network"));
         return;
     }
     const QString textToTranslate = d->inputText->toPlainText();
@@ -440,7 +455,7 @@ void TranslatorWidget::slotTranslateFailed(const QString &message)
     d->progressIndicator->hide();
     d->translatorResultTextEdit->clear();
     if (!message.isEmpty()) {
-        KMessageBox::error(this, message, i18n("Translate error"));
+        KMessageBox::error(this, message, i18nc("@title:window", "Translate error"));
     }
 }
 
@@ -448,7 +463,7 @@ void TranslatorWidget::slotInvertLanguage()
 {
     const QString fromLanguage = d->fromCombobox->itemData(d->fromCombobox->currentIndex()).toString();
     // don't invert when fromLanguage == auto
-    if (fromLanguage == QLatin1String("auto")) {
+    if (fromLanguage == "auto"_L1) {
         return;
     }
 
@@ -467,6 +482,7 @@ void TranslatorWidget::slotInvertLanguage()
 void TranslatorWidget::setStandalone(bool b)
 {
     d->standalone = b;
+    d->closeBtn->setVisible(b);
 }
 
 void TranslatorWidget::slotCloseWidget()
